
## CATO-CLI - mutation.policy.wanNetwork.updateRule:
[Click here](https://api.catonetworks.com/documentation/#mutation-updateRule) for documentation on this operation.

### Usage for mutation.policy.wanNetwork.updateRule:

`catocli mutation policy wanNetwork updateRule -h`

`catocli mutation policy wanNetwork updateRule <json>`

`catocli mutation policy wanNetwork updateRule "$(cat < updateRule.json)"`

`catocli mutation policy wanNetwork updateRule '{"wanNetworkPolicyMutationInput": {"policyMutationRevisionInput": {"id": {"id": "ID"}}}, "wanNetworkUpdateRuleInput": {"id": {"id": "ID"}, "wanNetworkUpdateRuleDataInput": {"application": {"appCategory": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "application": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "customApp": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "customCategory": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "customService": {"port": {"port": ["Port"]}, "portRange": {"from": {"from": "Port"}, "to": {"to": "Port"}}, "protocol": {"protocol": "enum(IpProtocol)"}}, "customServiceIp": {"ip": {"ip": "IPAddress"}, "ipRange": {"from": {"from": "IPAddress"}, "to": {"to": "IPAddress"}}, "name": {"name": "String"}}, "domain": {"domain": ["Domain"]}, "fqdn": {"fqdn": ["Fqdn"]}, "service": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}, "bandwidthPriority": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "configuration": {"activeTcpAcceleration": {"activeTcpAcceleration": "Boolean"}, "allocationIp": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "backhaulingSite": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "packetLossMitigation": {"packetLossMitigation": "Boolean"}, "popLocation": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "preserveSourcePort": {"preserveSourcePort": "Boolean"}, "primaryTransport": {"primaryInterfaceRole": {"primaryInterfaceRole": "enum(WanNetworkRuleInterfaceRole)"}, "secondaryInterfaceRole": {"secondaryInterfaceRole": "enum(WanNetworkRuleInterfaceRole)"}, "transportType": {"transportType": "enum(WanNetworkRuleTransportType)"}}, "secondaryTransport": {"primaryInterfaceRole": {"primaryInterfaceRole": "enum(WanNetworkRuleInterfaceRole)"}, "secondaryInterfaceRole": {"secondaryInterfaceRole": "enum(WanNetworkRuleInterfaceRole)"}, "transportType": {"transportType": "enum(WanNetworkRuleTransportType)"}}}, "description": {"description": "String"}, "destination": {"floatingSubnet": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "globalIpRange": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "group": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "host": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "ip": {"ip": ["IPAddress"]}, "ipRange": {"from": {"from": "IPAddress"}, "to": {"to": "IPAddress"}}, "networkInterface": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "site": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "siteNetworkSubnet": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "subnet": {"subnet": ["NetworkSubnet"]}, "systemGroup": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "user": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "usersGroup": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}, "enabled": {"enabled": "Boolean"}, "exceptions": {"application": {"appCategory": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "application": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "customApp": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "customCategory": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "customService": {"port": {"port": ["Port"]}, "portRange": {"from": {"from": "Port"}, "to": {"to": "Port"}}, "protocol": {"protocol": "enum(IpProtocol)"}}, "customServiceIp": {"ip": {"ip": "IPAddress"}, "ipRange": {"from": {"from": "IPAddress"}, "to": {"to": "IPAddress"}}, "name": {"name": "String"}}, "domain": {"domain": ["Domain"]}, "fqdn": {"fqdn": ["Fqdn"]}, "service": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}, "destination": {"floatingSubnet": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "globalIpRange": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "group": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "host": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "ip": {"ip": ["IPAddress"]}, "ipRange": {"from": {"from": "IPAddress"}, "to": {"to": "IPAddress"}}, "networkInterface": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "site": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "siteNetworkSubnet": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "subnet": {"subnet": ["NetworkSubnet"]}, "systemGroup": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "user": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "usersGroup": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}, "name": {"name": "String"}, "source": {"floatingSubnet": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "globalIpRange": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "group": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "host": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "ip": {"ip": ["IPAddress"]}, "ipRange": {"from": {"from": "IPAddress"}, "to": {"to": "IPAddress"}}, "networkInterface": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "site": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "siteNetworkSubnet": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "subnet": {"subnet": ["NetworkSubnet"]}, "systemGroup": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "user": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "usersGroup": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}}, "name": {"name": "String"}, "routeType": {"routeType": "enum(WanNetworkRuleRouteType)"}, "ruleType": {"ruleType": "enum(WanNetworkRuleType)"}, "source": {"floatingSubnet": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "globalIpRange": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "group": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "host": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "ip": {"ip": ["IPAddress"]}, "ipRange": {"from": {"from": "IPAddress"}, "to": {"to": "IPAddress"}}, "networkInterface": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "site": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "siteNetworkSubnet": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "subnet": {"subnet": ["NetworkSubnet"]}, "systemGroup": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "user": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "usersGroup": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}}}}'`

#### Operation Arguments for mutation.policy.wanNetwork.updateRule ####
`accountId` [ID] - (required) N/A 
`wanNetworkPolicyMutationInput` [WanNetworkPolicyMutationInput] - (optional) N/A 
`wanNetworkUpdateRuleInput` [WanNetworkUpdateRuleInput] - (required) N/A 
